@@ -21,8 +21,8 @@ def _log_request(method, url, params, headers, str_payload):
         logging.info(f"Request payload: {str_payload}")
 
 
-def _log_response(status_code, response):
-    logging.info(f"Response {status_code} {response}")
+def _log_response(status_code, response, headers):
+    logging.info(f"Response {status_code} {response} {headers}")
 
 
 class BaseClient(object):
@@ -93,6 +93,8 @@ class BaseClient(object):
         else:
             str_payload = ''
 
+        _log_request(method, url, params, headers, str_payload)
+
         try:
             if method == 'GET':
                 r = requests.get(url, params=params, data=str_payload, headers=headers, timeout=timeout)
@@ -116,8 +118,7 @@ class BaseClient(object):
                 logging.error(f"Error: {e}")
                 response = {}
 
-            _log_request(method, url, params, headers, str_payload)
-            _log_response(status_code, response_str)
+            _log_response(status_code, response_str, headers)
 
             return {
                 'status_code': status_code,
